@@ -121,6 +121,7 @@ typedef struct HildonDesktopHomeItemPriv_
   gint          delta_y;
   gboolean      overlaps;
   GtkAllocation old_allocation;
+  gint          last_press_x, last_press_y;
 
 } HildonDesktopHomeItemPriv;
 
@@ -644,6 +645,10 @@ hildon_desktop_home_item_realize (GtkWidget *widget)
                                            attributes_mask);
       gdk_window_set_user_data (priv->event_window, widget);
 
+      gdk_input_set_extension_events(priv->event_window,
+                                     gdk_window_get_events(priv->event_window),
+                                     GDK_EXTENSION_EVENTS_ALL);
+
       if (priv->resize_type != HILDON_DESKTOP_HOME_ITEM_RESIZE_NONE)
         {
           if (priv->resize_handle)
@@ -914,6 +919,8 @@ hildon_desktop_home_item_motion_notify (GtkWidget              *widget,
       event->window != priv->resize_handle_window)
     return FALSE;
 
+  gdk_event_request_motions (event);
+
   if (priv->state == HILDON_DESKTOP_HOME_ITEM_STATE_NORMAL &&
       !priv->click_timeout)
   {
@@ -1241,9 +1248,18 @@ hildon_desktop_home_item_propagate_button (HildonDesktopHomeItem *item,
   if (!priv->last_click_event)
     return;
 
+  /* When propagating ButtonRelease we still need to look for
+   * the window on which the button was _pressed_ */
+
+  if (press)
+  {
+    priv->last_press_x = priv->last_click_event->x;
+    priv->last_press_y = priv->last_click_event->y;
+  }
+
   child = hildon_desktop_home_item_get_window_at (item,
-                                                  priv->last_click_event->x,
-                                                  priv->last_click_event->y,
+                                                  priv->last_press_x,
+                                                  priv->last_press_y,
                                                   &x, &y);
 
   if (!child)
@@ -1251,9 +1267,10 @@ hildon_desktop_home_item_propagate_button (HildonDesktopHomeItem *item,
 
   event = (GdkEventButton *)gdk_event_copy ((GdkEvent *)priv->last_click_event);
 
-  event->x = x;
-  event->y = y;
-
+  /* When propagating ButtonRelease, add the offset between the
+   * press and release */
+  event->x = x + (priv->last_click_event->x - priv->last_press_x);
+  event->y = y + (priv->last_click_event->y - priv->last_press_y);
 
   /* Send synthetic enter event */
   crossing_event = (GdkEventCrossing *) gdk_event_new (GDK_ENTER_NOTIFY);
