@@ -96,6 +96,8 @@ struct _HildonDesktopPanelExpandablePrivate
   gboolean    filter_added;
   guint	      n_systray_applets;
 #endif
+
+  guint       fullscreen_handler;
 };
 
 enum
@@ -428,10 +430,11 @@ hildon_desktop_panel_expandable_constructor (GType gtype,
 
   HDWM *hdwm = hd_wm_get_singleton ();
 
-  g_signal_connect (hdwm, 
-		    "fullscreen",
-		    G_CALLBACK (hildon_desktop_panel_close_fullscreen),
-		    (gpointer)panel);
+  panel->priv->fullscreen_handler =
+      g_signal_connect (hdwm,
+                        "fullscreen",
+                        G_CALLBACK (hildon_desktop_panel_close_fullscreen),
+                        (gpointer)panel);
   
   return object;
 }
@@ -452,6 +455,17 @@ hildon_desktop_panel_expandable_finalize (GObject *object)
     gdk_window_remove_filter (panel->priv->invisible->window,
 		  	      hildon_desktop_x_event_filter,
 			      panel);
+
+  if (panel->priv->fullscreen_handler)
+  {
+    HDWM *wm = hd_wm_get_singleton ();
+
+    g_signal_handler_disconnect (wm,
+                                 panel->priv->fullscreen_handler);
+
+    panel->priv->fullscreen_handler = 0;
+  }
+
 #endif
   G_OBJECT_CLASS (hildon_desktop_panel_expandable_parent_class)->finalize (object);
 }
