@@ -501,7 +501,7 @@ hd_applications_menu_activate_app (GtkMenuItem *item, HDApplicationsMenu *button
     if (program)
     {
       gint argc;
-      gchar **argv;
+      gchar **argv = NULL;
       GPid child_pid;
       
       if (g_shell_parse_argv (program, &argc, &argv, &error))
@@ -527,6 +527,9 @@ hd_applications_menu_activate_app (GtkMenuItem *item, HDApplicationsMenu *button
     	      &child_pid,
     	      /* Return location for error */
     	      &error);
+
+        if (argv)
+          g_strfreev (argv);
       }
       
       if (error)
