@@ -2255,6 +2255,10 @@ hd_switcher_menu_changed_info_cb (HDWM *hdwm,
   {
     hd_switcher_menu_item_set_entry_info (HD_SWITCHER_MENU_ITEM (menu_item), info);
   }
+
+  /* The rest does not apply to hibernating entries (hopefully) */
+  if (hd_wm_entry_info_is_hibernating (info))
+    return;
   
   if (!hd_wm_entry_info_is_urgent (info) &&
        hd_wm_entry_info_get_ignore_urgent (info))
@@ -2346,8 +2350,9 @@ hd_switcher_menu_show_menu_cb (HDWM *hdwm, HDSwitcherMenu *switcher)
   }
   else if (GTK_WIDGET_VISIBLE (GTK_BIN (switcher->priv->toggle_button)->child))
   {
+#ifdef MAEMO_CHANGES	  
     gtk_window_close_other_temporaries (GTK_WINDOW (switcher->priv->popup_window));
-
+#endif
     gtk_toggle_button_set_active
       (GTK_TOGGLE_BUTTON (switcher->priv->toggle_button), TRUE);
   }
